from sklearn import datasets
from sklearn.model_selection import train_test_split
from sklearn.tree import DecisionTreeClassifier
from sklearn.neighbors import KNeighborsClassifier
from sklearn.svm import SVC
from sklearn.ensemble import VotingClassifier


# Loading some example data
iris = datasets.load_iris()
X = iris.data[:, [0, 2]]
y = iris.target

# Separamos los datos de entrenamiento y de prueba

X_train, X_test, y_train, y_test = train_test_split(
    X, y, random_state=456 )

# Training classifiers
clf1 = DecisionTreeClassifier(max_depth=4)
clf2 = KNeighborsClassifier(n_neighbors=7)
clf3 = SVC(kernel='rbf', probability=True)
eclf = VotingClassifier(estimators=[('dt', clf1), ('knn', clf2), ('svc', clf3)],
                        voting='soft', weights=[2, 2, 1])

clf1 = clf1.fit(X_train, y_train)
clf2 = clf2.fit(X_train, y_train)
clf3 = clf3.fit(X_train, y_train)

eclf = eclf.fit(X_train, y_train)

entrena = clf1.score( X_train, y_train )
prueba = clf1.score( X_test, y_test )
print( "Árbol de decision" )
print( "Entrenamiento:", entrena )
print( "Prueba       :", prueba )

entrena = clf2.score( X_train, y_train )
prueba = clf2.score( X_test, y_test )
print( "Vecinos más cercanos" )
print( "Entrenamiento:", entrena )
print( "Prueba       :", prueba )

entrena = clf3.score( X_train, y_train )
prueba = clf3.score( X_test, y_test )
print( "MVS" )
print( "Entrenamiento:", entrena )
print( "Prueba       :", prueba )

entrena = eclf.score( X_train, y_train )
prueba = eclf.score( X_test, y_test )
print( "Voto suave" )
print( "Entrenamiento:", entrena )
print( "Prueba       :", prueba )

